from celery.task import task

@task(name="dkeen-add-event")
def add_event_delayed(client, event_collection, event_body, timestamp):
    client.add_event(event_collection, event_body, timestamp)

@task(name="dkeen-add-events")
def add_events_delayed(client, events):
    client.add_events(events)


from django.conf import settings
from keen import KeenClient


class KeenBlockingClient(KeenClient):

    def __init__(self):
        super(KeenBlockingClient, self).__init__(
            project_id=settings.KEEN_PROJECT_ID,
            write_key=settings.KEEN_WRITE_KEY,
            read_key=settings.KEEN_READ_KEY,
        )


class KeenCeleryClient(KeenBlockingClient):

    def add_event(self, event_collection, event_body, timestamp=None):
        from .tasks import add_event_delayed
        add_event_delayed.delay(KeenBlockingClient(), event_collection, event_body, timestamp)

    def add_events(self, events):
        from .tasks import add_events_delayed
        add_events_delayed.delay(KeenBlockingClient(), events)


def get_client():
    return KeenCeleryClient() if settings.KEEN_CELERY else KeenBlockingClient()


def add_event(event_collection, event_body, timestamp=None):
    client = get_client()
    client.add_event(event_collection, event_body, timestamp)


def add_events(events):
    client = get_client()
    client.add_events(events)


import os
from setuptools import setup

with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='django-keen',
    version='0.1.3',
    author='Jannis Gebauer',
    author_email='ja.geb@pricemesh.io',
    packages=['dkeen',],
    url='http://pypi.python.org/pypi/django-keen/',
    license='LICENSE.txt',
    description='Simple wrapper for django around the official keen.io client',
    long_description=open('README.md').read(),
    install_requires=required
)